@@ -14,7 +14,7 @@ from ..utils.kabaret.subprocess_manager.flow import RunAction
 from ..resources.icons import flow as flow_icons
 
 
-CHOICES = ["blend", "kra", "png", "jpg", "txt", "abc", "mov", "psd", "aep", "zip", "mp4", "fbx", "ai", "json", "jsx", "obj"]
+CHOICES = ["blend", "kra", "png", "jpg", "txt", "abc", "mov", "psd", "aep", "zip", "mp4", "fbx", "ai", "json", "jsx", "obj", "wav"]
 CHOICES_ICONS = {
             "blend": ("icons.libreflow", "blender"),
             "kra": ("icons.libreflow", "krita"),
@@ -32,6 +32,7 @@ CHOICES_ICONS = {
             "json": ("icons.libreflow", "json"),
             "jsx": ("icons.libreflow", "jsx"),
             "obj": ("icons.libreflow", "3d-object"),
+            "wav": ("icons.gui", "youtube-logo"),
         }
 
 
