@@ -78,9 +78,10 @@ class PlayLastBlastAction(baseflow.file.OpenWithDefaultApp):
         if not parent.files.has_mapped_name("preview"):
             return True
 
-        contextual_dict = get_contextual_dict(parent, "settings", ["path"])
         preview_folder_path = os.path.join(
-            self.root().project().get_root(), contextual_dict["path"], "preview"
+            self.root().project().get_root(),
+            parent.path.get(),
+            "preview"
         )
         files = os.listdir(preview_folder_path)
         files = map(lambda f: os.path.join(preview_folder_path, f), files)
