@@ -1,7 +1,7 @@
-import kabaret.subprocess_manager as ksm
+from kabaret.subprocess_manager.flow import RunAction as KabaretSMRunAction
 
 
-class RunAction(ksm.flow.RunAction):
+class RunAction(KabaretSMRunAction):
 
     @classmethod
     def get_result(
